@@ -36,6 +36,7 @@ def get_option_parser():
     cases.add_option('--dataset', dest='dataset', default=False, action='store_true', help='dataset tests')
     cases.add_option('--db-url', dest='db_url', default=False, action='store_true', help='db url tests')
     cases.add_option('--djpeewee', dest='djpeewee', default=False, action='store_true', help='djpeewee tests')
+    cases.add_option('--fields', dest='fields', default=False, action='store_true', help='extra field tests')
     cases.add_option('--flask', dest='flask', default=False, action='store_true', help='flask utils tests')
     cases.add_option('--gfk', dest='gfk', default=False, action='store_true', help='gfk tests')
     cases.add_option('--hybrid', dest='hybrid', default=False, action='store_true', help='hybrid property/method tests')
@@ -50,6 +51,7 @@ def get_option_parser():
     cases.add_option('--signals', dest='signals', default=False, action='store_true', help='signals tests')
     cases.add_option('--shortcuts', dest='shortcuts', default=False, action='store_true', help='shortcuts tests')
     cases.add_option('--sqlcipher-ext', dest='sqlcipher', default=False, action='store_true', help='sqlcipher_ext tests (requires pysqlcipher)')
+    cases.add_option('--sqlite-c-ext', dest='sqlite_c', default=False, action='store_true', help='sqlite c extension tests')
     cases.add_option('--sqlite-ext', dest='sqlite_ext', default=False, action='store_true', help='sqlite_ext tests')
     cases.add_option('--test-utils', dest='test_utils', default=False, action='store_true', help='test_utils tests')
 
@@ -85,6 +87,12 @@ def collect_modules(options):
     if xtra(options.djpeewee):
         from playhouse.tests import test_djpeewee
         modules.append(test_djpeewee)
+    if xtra(options.fields):
+        from playhouse.tests import test_extra_fields
+        from playhouse.tests import test_manytomany
+        modules.append(test_extra_fields)
+        if test_manytomany not in modules:
+            modules.append(test_manytomany)
     if xtra(options.flask):
         try:
             import flask
@@ -104,7 +112,8 @@ def collect_modules(options):
         modules.append(test_kv)
     if xtra(options.manytomany):
         from playhouse.tests import test_manytomany
-        modules.append(test_manytomany)
+        if test_manytomany not in modules:
+            modules.append(test_manytomany)
     if xtra(options.migrations):
         try:
             from playhouse.tests import test_migrate
@@ -136,17 +145,20 @@ def collect_modules(options):
         from playhouse.tests import test_signals
         modules.append(test_signals)
     if xtra(options.shortcuts):
-        from playhouse.tests import test_manytomany
         from playhouse.tests import test_shortcuts
         modules.append(test_shortcuts)
-        if test_manytomany not in modules:
-            modules.append(test_manytomany)
     if xtra(options.sqlcipher):
         try:
             from playhouse.tests import test_sqlcipher_ext
             modules.append(test_sqlcipher_ext)
         except ImportError:
             print_('Unable to import pysqlcipher tests, skipping')
+    if xtra(options.sqlite_c):
+        try:
+            from playhouse.tests import test_sqlite_c_ext
+            modules.append(test_sqlite_c_ext)
+        except ImportError:
+            print_('Unable to import SQLite C extension tests, skipping')
     if xtra(options.sqlite_ext):
         from playhouse.tests import test_sqlite_ext
         modules.append(test_sqlite_ext)
